@@ -27,11 +27,11 @@
 #include "H5Tprivate.h"  
 #include "H5TSprivate.h" 
 
-static FILE r_stdout_sentinel;
-static FILE r_stderr_sentinel;
+static char r_stdout_sentinel;
+static char r_stderr_sentinel;
 
-H5_DLL FILE *Rstdout = &r_stdout_sentinel;
-H5_DLL FILE *Rstderr = &r_stderr_sentinel;
+H5_DLL FILE *Rstdout = (FILE *)&r_stdout_sentinel;
+H5_DLL FILE *Rstderr = (FILE *)&r_stderr_sentinel;
 
 H5_DLL int Rfprintf(FILE *stream, const char *format, ...) {
     int ret = 0;
